@@ -5,14 +5,20 @@ cp("./docs/Project.toml", "./docs/src/assets/Project.toml", force = true)
 
 include("pages.jl")
 
-makedocs(sitename = "RecursiveArrayTools.jl",
+makedocs(
+    sitename = "RecursiveArrayTools.jl",
     authors = "Chris Rackauckas",
     modules = [RecursiveArrayTools],
     clean = true, doctest = false, linkcheck = true,
     warnonly = [:missing_docs],
-    format = Documenter.HTML(assets = ["assets/favicon.ico"],
-        canonical = "https://docs.sciml.ai/RecursiveArrayTools/stable/"),
-    pages = pages)
+    format = Documenter.HTML(
+        assets = ["assets/favicon.ico"],
+        canonical = "https://docs.sciml.ai/RecursiveArrayTools/stable/"
+    ),
+    pages = pages
+)
 
-deploydocs(repo = "github.com/SciML/RecursiveArrayTools.jl.git";
-    push_preview = true)
+deploydocs(
+    repo = "github.com/SciML/RecursiveArrayTools.jl.git";
+    push_preview = true
+)
