@@ -1,4 +1,4 @@
-using RecursiveArrayTools, CUDA, Test, Adapt
+using RecursiveArrayTools, ArrayInterface, CUDA, Adapt, Test
 CUDA.allowscalar(false)
 
 # Test indexing with colon
@@ -24,13 +24,13 @@ b = ArrayPartition(([0.0f0] |> cu, [0.0f0] |> cu, [0.0f0] |> cu))
 
 # Test adapt from ArrayPartition with CuArrays to ArrayPartition with CPU arrays
 
-a = CuArray(Float64.([1., 2., 3., 4.]))
-b = CuArray(Float64.([1., 2., 3., 4.]))
+a = CuArray(Float64.([1.0, 2.0, 3.0, 4.0]))
+b = CuArray(Float64.([1.0, 2.0, 3.0, 4.0]))
 part_a_gpu = ArrayPartition(a, b)
 part_a = adapt(Array{Float32}, part_a_gpu)
 
-c = Float32.([1., 2., 3., 4.])
-d = Float32.([1., 2., 3., 4.])
+c = Float32.([1.0, 2.0, 3.0, 4.0])
+d = Float32.([1.0, 2.0, 3.0, 4.0])
 part_b = ArrayPartition(c, d)
 
 @test part_a == part_b # Test equality
@@ -40,4 +40,9 @@ for i in 1:length(part_a.x)
     sub_b = part_b.x[i]
     @test sub_a == sub_b # Test for value equality in sub-arrays
     @test typeof(sub_a) === typeof(sub_b) # Test type equality
-end
\ No newline at end of file
+end
+
+x = ArrayPartition((CUDA.zeros(2), CUDA.zeros(2)))
+@test ArrayInterface.zeromatrix(x) isa CuMatrix
+@test size(ArrayInterface.zeromatrix(x)) == (4, 4)
+@test maximum(abs, x) == 0.0f0
